@@ -1,12 +1,12 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 import warnings
 
+import torch
 import torch.nn as nn
-
-from .registry import ACTIVATION_LAYERS
+from mmengine.registry import MODELS
 
 
-@ACTIVATION_LAYERS.register_module()
+@MODELS.register_module()
 class HSigmoid(nn.Module):
     """Hard Sigmoid Module. Apply the hard sigmoid function:
     Hsigmoid(x) = min(max((x + bias) / divisor, min_value), max_value)
@@ -26,7 +26,11 @@ class HSigmoid(nn.Module):
         Tensor: The output tensor.
     """
 
-    def __init__(self, bias=3.0, divisor=6.0, min_value=0.0, max_value=1.0):
+    def __init__(self,
+                 bias: float = 3.0,
+                 divisor: float = 6.0,
+                 min_value: float = 0.0,
+                 max_value: float = 1.0):
         super().__init__()
         warnings.warn(
             'In MMCV v1.4.4, we modified the default value of args to align '
@@ -40,7 +44,7 @@ class HSigmoid(nn.Module):
         self.min_value = min_value
         self.max_value = max_value
 
-    def forward(self, x):
+    def forward(self, x: torch.Tensor) -> torch.Tensor:
         x = (x + self.bias) / self.divisor
 
         return x.clamp_(self.min_value, self.max_value)
